pub struct IntegrationRuntimeCustomSetupScriptProperties {
pub blob_container_uri: Option<String>,
pub sas_token: Option<SecureString>,
}Expand description
Custom setup script properties for a managed dedicated integration runtime.
Fields
blob_container_uri: Option<String>The URI of the Azure blob container that contains the custom setup script.
sas_token: Option<SecureString>Azure Synapse secure string definition. The string value will be masked with asterisks ‘*’ during Get or List API calls.
Implementations